@@ -1,9 +1,8 @@
 // Copyright 2020-2021 the Deno authors. All rights reserved. MIT license.
 use anyhow::bail;
 use anyhow::Error as AnyError;
-use deno_lint::rules::{get_all_rules, LintRule};
+use deno_lint::rules::{get_filtered_rules, LintRule};
 use serde::Deserialize;
-use std::collections::HashMap;
 use std::path::Path;
 use std::path::PathBuf;
 
@@ -31,34 +30,11 @@ pub struct Config {
 
 impl Config {
   pub fn get_rules(&self) -> Vec<Box<dyn LintRule>> {
-    let mut rules = HashMap::new();
-
-    for config_tag in self.rules.tags.iter() {
-      rules.extend(get_all_rules().into_iter().filter_map(|rule| {
-        let code = rule.code();
-        if rule.tags().contains(&config_tag.as_str()) {
-          Some((code, rule))
-        } else {
-          None
-        }
-      }));
-    }
-
-    for exclude in self.rules.exclude.iter() {
-      rules.remove(exclude.as_str());
-    }
-
-    let mut rules_per_code = get_all_rules()
-      .into_iter()
-      .map(|rule| (rule.code(), rule))
-      .collect::<HashMap<_, _>>();
-    for include in self.rules.include.iter() {
-      if let Some(rule) = rules_per_code.remove(include.as_str()) {
-        rules.insert(include, rule);
-      }
-    }
-
-    rules.into_iter().map(|(_code, rule)| rule).collect()
+    get_filtered_rules(
+      Some(self.rules.tags.clone()),
+      Some(self.rules.exclude.clone()),
+      Some(self.rules.include.clone()),
+    )
   }
 
   pub fn get_files(&self) -> Result<Vec<PathBuf>, AnyError> {
