@@ -2,6 +2,7 @@
 use crate::context::Context;
 use crate::Program;
 use crate::ProgramRef;
+use std::collections::HashSet;
 
 pub mod adjacent_overload_signatures;
 pub mod ban_ts_comment;
@@ -79,6 +80,7 @@ pub mod no_unsafe_negation;
 pub mod no_unused_labels;
 pub mod no_unused_vars;
 pub mod no_var;
+pub mod no_window_prefix;
 pub mod no_with;
 pub mod prefer_as_const;
 pub mod prefer_const;
@@ -214,6 +216,7 @@ pub fn get_all_rules() -> Vec<Box<dyn LintRule>> {
     no_unused_labels::NoUnusedLabels::new(),
     no_unused_vars::NoUnusedVars::new(),
     no_var::NoVar::new(),
+    no_window_prefix::NoWindowPrefix::new(),
     no_with::NoWith::new(),
     prefer_as_const::PreferAsConst::new(),
     prefer_const::PreferConst::new(),
@@ -235,6 +238,62 @@ pub fn get_recommended_rules() -> Vec<Box<dyn LintRule>> {
     .collect()
 }
 
+/// Returns a list of rules after filtering.
+///
+/// Following rules are applied (in the described order):
+///
+/// - if `maybe_tags` is `None` then all defined rules are returned, otherwise
+///   only rules matching at least one tag will be returned; if provided list
+///   is empty then all rules will be excluded by default
+///
+/// - if `maybe_exclude` is `Some`, all rules with matching codes will
+///   be filtered out
+///
+/// - if `maybe_include` is `Some`, rules with matching codes will be added
+///   to the return list
+///
+/// Before returning the list will sorted alphabetically.
+pub fn get_filtered_rules(
+  maybe_tags: Option<Vec<String>>,
+  maybe_exclude: Option<Vec<String>>,
+  maybe_include: Option<Vec<String>>,
+) -> Vec<Box<dyn LintRule>> {
+  let tags_set =
+    maybe_tags.map(|tags| tags.into_iter().collect::<HashSet<_>>());
+
+  let mut rules = get_all_rules()
+    .into_iter()
+    .filter(|rule| {
+      let mut passes = if let Some(tags_set) = &tags_set {
+        rule
+          .tags()
+          .iter()
+          .any(|t| tags_set.contains(&t.to_string()))
+      } else {
+        true
+      };
+
+      if let Some(excludes) = &maybe_exclude {
+        if excludes.contains(&rule.code().to_owned()) {
+          passes &= false;
+        }
+      }
+
+      if let Some(includes) = &maybe_include {
+        if includes.contains(&rule.code().to_owned()) {
+          passes |= true;
+        }
+      }
+
+      passes
+    })
+    .collect::<Vec<_>>();
+
+  rules.sort_by_key(|r| r.code());
+
+  rules
+}
+
 #[cfg(test)]
 mod tests {
   use super::*;
@@ -258,4 +317,47 @@ mod tests {
       assert_eq!(sorted.code(), unsorted.code());
     }
   }
+
+  #[test]
+  fn test_get_filtered_rules() {
+    let rules =
+      get_filtered_rules(Some(vec!["recommended".to_string()]), None, None);
+    for (r, rr) in rules.into_iter().zip(get_recommended_rules()) {
+      assert_eq!(r.code(), rr.code());
+    }
+
+    let rules = get_filtered_rules(
+      Some(vec!["recommended".to_string()]),
+      None,
+      Some(vec!["ban-untagged-todo".to_string()]),
+    );
+    assert_eq!(rules.len(), get_recommended_rules().len() + 1);
+
+    let rules = get_filtered_rules(Some(vec![]), None, None);
+    assert!(rules.is_empty());
+
+    let rules = get_filtered_rules(
+      Some(vec![]),
+      None,
+      Some(vec!["ban-untagged-todo".to_string()]),
+    );
+    assert_eq!(rules.len(), 1);
+
+    let rules = get_filtered_rules(
+      Some(vec![]),
+      Some(vec![
+        "ban-untagged-todo".to_string(),
+        "no-const-assign".to_string(),
+      ]),
+      Some(vec!["ban-untagged-todo".to_string()]),
+    );
+    assert_eq!(rules.len(), 1);
+
+    let rules = get_filtered_rules(
+      Some(vec!["recommended".to_string()]),
+      Some(vec!["ban-ts-comment".to_string()]),
+      Some(vec!["ban-untagged-todo".to_string()]),
+    );
+    assert_eq!(rules.len(), get_recommended_rules().len());
+  }
 }
