@@ -1,5 +1,6 @@
 // Copyright 2020-2021 the Deno authors. All rights reserved. MIT license.
-use super::{Context, LintRule, ProgramRef, DUMMY_NODE};
+use super::{Context, LintRule, DUMMY_NODE};
+use crate::ProgramRef;
 use derive_more::Display;
 use swc_ecmascript::ast::Expr;
 use swc_ecmascript::ast::UnaryExpr;
@@ -49,33 +50,9 @@ impl LintRule for NoDeleteVar {
     }
   }
 
+  #[cfg(feature = "docs")]
   fn docs(&self) -> &'static str {
-    r#"Disallows the deletion of variables
-
-`delete` is used to remove a property from an object.  Variables declared via
-`var`, `let` and `const` cannot be deleted (`delete` will return `false`).  Setting
-`strict` mode on will raise a syntax error when attempting to delete a variable.
-
-### Invalid:
-
-```typescript
-const a = 1;
-let b = 2;
-let c = 3;
-delete a; // would return false
-delete b; // would return false
-delete c; // would return false
-```
-
-### Valid:
-
-```typescript
-let obj = {
-  a: 1,
-};
-delete obj.a; // return true
-```
-"#
+    include_str!("../../docs/rules/no_delete_var.md")
   }
 }
 
