@@ -1,5 +1,6 @@
 // Copyright 2020-2021 the Deno authors. All rights reserved. MIT license.
-use super::{Context, LintRule, ProgramRef, DUMMY_NODE};
+use super::{Context, LintRule, DUMMY_NODE};
+use crate::ProgramRef;
 use derive_more::Display;
 use std::collections::HashSet;
 use swc_ecmascript::ast::{Expr, SwitchStmt};
@@ -49,44 +50,9 @@ impl LintRule for NoDuplicateCase {
     }
   }
 
+  #[cfg(feature = "docs")]
   fn docs(&self) -> &'static str {
-    r#"Disallows using the same case clause in a switch statement more than once
-
-When you reuse a case test expression in a `switch` statement, the duplicate case will
-never be reached meaning this is almost always a bug.
-
-### Invalid:
-
-```typescript
-const someText = "a";
-switch (someText) {
-  case "a": // (1)
-    break;
-  case "b":
-    break;
-  case "a": // duplicate of (1)
-    break;
-  default:
-    break;
-}
-```
-
-### Valid:
-
-```typescript
-const someText = "a";
-switch (someText) {
-  case "a":
-    break;
-  case "b":
-    break;
-  case "c":
-    break;
-  default:
-    break;
-}
-```
-"#
+    include_str!("../../docs/rules/no_duplicate_case.md")
   }
 }
 
