@@ -1,5 +1,6 @@
 // Copyright 2020-2021 the Deno authors. All rights reserved. MIT license.
-use super::{Context, LintRule, ProgramRef, DUMMY_NODE};
+use super::{Context, LintRule, DUMMY_NODE};
+use crate::ProgramRef;
 use swc_ecmascript::ast::{ArrayPat, ObjectPat, ObjectPatProp};
 use swc_ecmascript::visit::noop_visit_type;
 use swc_ecmascript::visit::Node;
@@ -37,43 +38,9 @@ impl LintRule for NoEmptyPattern {
     }
   }
 
+  #[cfg(feature = "docs")]
   fn docs(&self) -> &'static str {
-    r#"Disallows the use of empty patterns in destructuring
-
-In destructuring, it is possible to use empty patterns such as `{}` or `[]` which
-have no effect, most likely not what the author intended.
-
-### Invalid:
-
-```typescript
-// In these examples below, {} and [] are not object literals or empty arrays,
-// but placeholders for destructured variable names
-const {} = someObj;
-const [] = someArray;
-const {a: {}} = someObj;
-const [a: []] = someArray;
-function myFunc({}) {}
-function myFunc([]) {}
-```
-
-### Valid:
-
-```typescript
-const {a} = someObj;
-const [a] = someArray;
-
-// Correct way to default destructured variable to object literal
-const {a = {}} = someObj;
-
-// Correct way to default destructured variable to empty array
-const [a = []] = someArray;
-
-function myFunc({a}) {}
-function myFunc({a = {}}) {}
-function myFunc([a]) {}
-function myFunc([a = []]) {}
-```
-"#
+    include_str!("../../docs/rules/no_empty_pattern.md")
   }
 }
 
