@@ -1,6 +1,7 @@
 // Copyright 2020-2021 the Deno authors. All rights reserved. MIT license.
-use super::{Context, LintRule, ProgramRef, DUMMY_NODE};
+use super::{Context, LintRule, DUMMY_NODE};
 use crate::swc_util::StringRepr;
+use crate::ProgramRef;
 use swc_common::Span;
 use swc_ecmascript::ast::CallExpr;
 use swc_ecmascript::ast::Expr;
@@ -38,28 +39,9 @@ impl LintRule for NoEval {
     }
   }
 
+  #[cfg(feature = "docs")]
   fn docs(&self) -> &'static str {
-    r#"Disallows the use of `eval`
-
-`eval` is a potentially dangerous function which can open your code to a number
-of security vulnerabilities.  In addition to being slow, `eval` is also often
-unnecessary with better solutions available.
-
-### Invalid:
-
-```typescript
-const obj = { x: "foo" };
-const key = "x",
-const value = eval("obj." + key);
-```
-
-### Valid:
-
-```typescript
-const obj = { x: "foo" };
-const value = obj[x];
-```
-"#
+    include_str!("../../docs/rules/no_eval.md")
   }
 }
 
