@@ -1,5 +1,6 @@
 // Copyright 2020-2021 the Deno authors. All rights reserved. MIT license.
-use super::{Context, LintRule, ProgramRef, DUMMY_NODE};
+use super::{Context, LintRule, DUMMY_NODE};
+use crate::ProgramRef;
 use derive_more::Display;
 use swc_common::Span;
 use swc_ecmascript::ast::Expr;
@@ -50,34 +51,9 @@ impl LintRule for NoExtraNonNullAssertion {
     }
   }
 
+  #[cfg(feature = "docs")]
   fn docs(&self) -> &'static str {
-    r#"Disallows unnecessary non-null assertions
-
-Non-null assertions are specified with an `!` saying to the compiler that you
-know this value is not null.  Specifying this operator more than once in a row,
-or in combination with the optional chaining operator (`?`) is confusing and
-unnecessary.
-
-### Invalid:
-
-```typescript
-const foo: { str: string } | null = null;
-const bar = foo!!.str;
-
-function myFunc(bar: undefined | string) { return bar!!; }
-function anotherFunc(bar?: { str: string }) { return bar!?.str; }
-```
-
-### Valid:
-
-```typescript
-const foo: { str: string } | null = null;
-const bar = foo!.str;
-
-function myFunc(bar: undefined | string) { return bar!; }
-function anotherFunc(bar?: { str: string }) { return bar?.str; }
-```
-"#
+    include_str!("../../docs/rules/no_extra_non_null_assertion.md")
   }
 }
 
