@@ -1,5 +1,6 @@
 // Copyright 2020-2021 the Deno authors. All rights reserved. MIT license.
-use super::{Context, LintRule, ProgramRef, DUMMY_NODE};
+use super::{Context, LintRule, DUMMY_NODE};
+use crate::ProgramRef;
 use derive_more::Display;
 use swc_common::{comments::Comment, Span, Spanned, DUMMY_SP};
 use swc_ecmascript::{
@@ -50,55 +51,9 @@ impl LintRule for NoFallthrough {
     }
   }
 
+  #[cfg(feature = "docs")]
   fn docs(&self) -> &'static str {
-    r#"Disallows the implicit fallthrough of case statements
-
-Case statements without a `break` will execute their body and then fallthrough
-to the next case or default block and execute this block as well.  While this
-is sometimes intentional, many times the developer has forgotten to add a break
-statement, intending only for a single case statement to be executed.  This
-rule enforces that you either end each case statement with a break statement or
-an explicit comment that fallthrough was intentional.  The fallthrough comment
-must contain one of `fallthrough`, `falls through` or `fall through`.
-
-### Invalid:
-
-```typescript
-switch (myVar) {
-  case 1:
-    console.log('1');
-
-  case 2:
-    console.log('2');
-}
-// If myVar = 1, outputs both `1` and `2`.  Was this intentional?
-```
-
-### Valid:
-
-```typescript
-switch (myVar) {
-  case 1:
-    console.log('1');
-    break;
-
-  case 2:
-    console.log('2');
-    break;
-}
-// If myVar = 1, outputs only `1`
-
-switch (myVar) {
-  case 1:
-    console.log('1');
-    /* falls through */
-
-  case 2:
-    console.log('2');
-}
-// If myVar = 1, intentionally outputs both `1` and `2`
-```
-"#
+    include_str!("../../docs/rules/no_fallthrough.md")
   }
 }
 
@@ -159,12 +114,20 @@ impl<'c, 'view> Visit for NoFallthroughVisitor<'c, 'view> {
           hi: cases[case_idx + 1].span.lo(),
           ctxt: case.span.ctxt,
         };
-        let span_lines = self.context.source_map().span_to_lines(span).unwrap();
+        // todo(dsherret): use `span.line_start_fast(context.program)` and
+        // `line_end_fast` when switching to ast_view
+        let span_line_count = self
+          .context
+          .file_text_substring(&span)
+          .chars()
+          .filter(|c| *c == '\n')
+          .count()
+          + 1;
         // When the case body contains only new lines `case.cons` will be empty.
         // This means there are no statements detected so we must detect case
         // bodies made up of only new lines by counting the total amount of new lines.
         // If there's more than 2 new lines and `case.cons` is empty this indicates the case body only contains new lines.
-        should_emit_err = span_lines.lines.len() > 2;
+        should_emit_err = span_line_count > 2;
       }
 
       prev_span = case.span;
