@@ -1,5 +1,6 @@
 // Copyright 2020-2021 the Deno authors. All rights reserved. MIT license.
-use super::{Context, LintRule, ProgramRef, DUMMY_NODE};
+use super::{Context, LintRule, DUMMY_NODE};
+use crate::ProgramRef;
 use derive_more::Display;
 use swc_ecmascript::ast::{Expr, ExprOrSuper};
 use swc_ecmascript::visit::Node;
@@ -39,6 +40,11 @@ impl LintRule for NoNonNullAssertedOptionalChain {
       ProgramRef::Script(s) => visitor.visit_script(s, &DUMMY_NODE),
     }
   }
+
+  #[cfg(feature = "docs")]
+  fn docs(&self) -> &'static str {
+    include_str!("../../docs/rules/no_non_null_asserted_optional_chain.md")
+  }
 }
 
 struct NoNonNullAssertedOptionalChainVisitor<'c, 'view> {
