@@ -1,5 +1,6 @@
 // Copyright 2020-2021 the Deno authors. All rights reserved. MIT license.
-use super::{Context, LintRule, ProgramRef, DUMMY_NODE};
+use super::{Context, LintRule, DUMMY_NODE};
+use crate::ProgramRef;
 use derive_more::Display;
 use swc_ecmascript::visit::Node;
 use swc_ecmascript::visit::Visit;
@@ -34,6 +35,11 @@ impl LintRule for NoNonNullAssertion {
       ProgramRef::Script(s) => visitor.visit_script(s, &DUMMY_NODE),
     }
   }
+
+  #[cfg(feature = "docs")]
+  fn docs(&self) -> &'static str {
+    include_str!("../../docs/rules/no_non_null_assertion.md")
+  }
 }
 
 struct NoNonNullAssertionVisitor<'c, 'view> {
