@@ -7,11 +7,8 @@ use swc_ecmascript::{
   ast::*,
   utils::ident::IdentLike,
   visit::Node,
-  visit::{noop_visit_type, Visit, VisitAll, VisitAllWith, VisitWith},
+  visit::{noop_visit_type, Visit, VisitWith},
 };
-use swc_ecmascript::{utils::find_ids, utils::Id};
-
-use std::collections::HashSet;
 
 pub struct NoUndef;
 
@@ -29,15 +26,7 @@ impl LintRule for NoUndef {
     context: &mut Context<'view>,
     program: ProgramRef<'view>,
   ) {
-    let mut collector = BindingCollector {
-      declared: Default::default(),
-    };
-    match program {
-      ProgramRef::Module(m) => m.visit_all_with(&DUMMY_NODE, &mut collector),
-      ProgramRef::Script(s) => s.visit_all_with(&DUMMY_NODE, &mut collector),
-    }
-
-    let mut visitor = NoUndefVisitor::new(context, collector.declared);
+    let mut visitor = NoUndefVisitor::new(context);
     match program {
       ProgramRef::Module(m) => m.visit_with(&DUMMY_NODE, &mut visitor),
       ProgramRef::Script(s) => s.visit_with(&DUMMY_NODE, &mut visitor),
@@ -50,135 +39,13 @@ impl LintRule for NoUndef {
   }
 }
 
-struct BindingCollector {
-  /// If there exists a binding with such id, it's not global.
-  declared: HashSet<Id>,
-}
-
-impl BindingCollector {
-  fn declare(&mut self, i: Id) {
-    self.declared.insert(i);
-  }
-}
-
-impl VisitAll for BindingCollector {
-  fn visit_fn_decl(&mut self, f: &FnDecl, _: &dyn Node) {
-    self.declare(f.ident.to_id());
-  }
-
-  fn visit_class_decl(&mut self, f: &ClassDecl, _: &dyn Node) {
-    self.declare(f.ident.to_id());
-  }
-
-  fn visit_class_expr(&mut self, n: &ClassExpr, _: &dyn Node) {
-    if let Some(i) = &n.ident {
-      self.declare(i.to_id());
-    }
-  }
-
-  fn visit_import_named_specifier(
-    &mut self,
-    i: &ImportNamedSpecifier,
-    _: &dyn Node,
-  ) {
-    self.declare(i.local.to_id());
-  }
-
-  fn visit_import_default_specifier(
-    &mut self,
-    i: &ImportDefaultSpecifier,
-    _: &dyn Node,
-  ) {
-    self.declare(i.local.to_id());
-  }
-
-  fn visit_import_star_as_specifier(
-    &mut self,
-    i: &ImportStarAsSpecifier,
-    _: &dyn Node,
-  ) {
-    self.declare(i.local.to_id());
-  }
-
-  fn visit_export_default_decl(&mut self, e: &ExportDefaultDecl, _: &dyn Node) {
-    if let DefaultDecl::Class(ClassExpr {
-      ident: Some(ref ident),
-      ..
-    })
-    | DefaultDecl::Fn(FnExpr {
-      ident: Some(ref ident),
-      ..
-    })
-    | DefaultDecl::TsInterfaceDecl(TsInterfaceDecl {
-      id: ref ident, ..
-    }) = e.decl
-    {
-      self.declare(ident.to_id());
-    }
-  }
-
-  fn visit_var_declarator(&mut self, v: &VarDeclarator, _: &dyn Node) {
-    let ids: Vec<Id> = find_ids(&v.name);
-    for id in ids {
-      self.declare(id);
-    }
-  }
-
-  fn visit_ts_type_alias_decl(&mut self, t: &TsTypeAliasDecl, _: &dyn Node) {
-    self.declare(t.id.to_id());
-  }
-
-  fn visit_ts_enum_decl(&mut self, e: &TsEnumDecl, _: &dyn Node) {
-    self.declare(e.id.to_id());
-  }
-
-  fn visit_ts_param_prop_param(&mut self, p: &TsParamPropParam, _: &dyn Node) {
-    match p {
-      TsParamPropParam::Ident(i) => {
-        self.declare(i.to_id());
-      }
-      TsParamPropParam::Assign(i) => {
-        let ids: Vec<Id> = find_ids(&i.left);
-        for id in ids {
-          self.declare(id);
-        }
-      }
-    }
-  }
-
-  fn visit_param(&mut self, p: &Param, _: &dyn Node) {
-    let ids: Vec<Id> = find_ids(&p.pat);
-    for id in ids {
-      self.declare(id);
-    }
-  }
-
-  fn visit_catch_clause(&mut self, c: &CatchClause, _: &dyn Node) {
-    if let Some(pat) = &c.param {
-      let ids: Vec<Id> = find_ids(pat);
-      for id in ids {
-        self.declare(id);
-      }
-    }
-  }
-
-  /// See https://github.com/denoland/deno_lint/issues/596
-  fn visit_arrow_expr(&mut self, e: &ArrowExpr, _: &dyn Node) {
-    let ids: Vec<Id> = find_ids(&e.params);
-    for id in ids {
-      self.declare(id);
-    }
-  }
-}
-
 struct NoUndefVisitor<'c, 'view> {
   context: &'c mut Context<'view>,
-  declared: HashSet<Id>,
 }
 
 impl<'c, 'view> NoUndefVisitor<'c, 'view> {
-  fn new(context: &'c mut Context<'view>, declared: HashSet<Id>) -> Self {
-    Self { context, declared }
+  fn new(context: &'c mut Context<'view>) -> Self {
+    Self { context }
   }
 
   fn check(&mut self, ident: &Ident) {
@@ -196,8 +63,7 @@ impl<'c, 'view> NoUndefVisitor<'c, 'view> {
       return;
     }
 
-    // Ignore top level bindings declared in the file.
-    if self.declared.contains(&ident.to_id()) {
+    if self.context.scope().var(&ident.to_id()).is_some() {
       return;
     }
 
