@@ -1,8 +1,9 @@
 // Copyright 2020-2021 the Deno authors. All rights reserved. MIT license.
-use super::{Context, LintRule, ProgramRef};
+use super::{Context, LintRule};
 use crate::handler::{Handler, Traverse};
+use crate::{Program, ProgramRef};
+use ast_view::NodeTrait;
 use derive_more::Display;
-use dprint_swc_ecma_ast_view::{self as AstView, NodeTrait};
 use swc_common::{Span, Spanned};
 
 pub struct NoUnsafeFinally;
@@ -54,63 +55,25 @@ impl LintRule for NoUnsafeFinally {
   fn lint_program_with_ast_view(
     &self,
     context: &mut Context,
-    program: dprint_swc_ecma_ast_view::Program<'_>,
+    program: Program<'_>,
   ) {
     NoUnsafeFinallyHandler.traverse(program, context);
   }
 
+  #[cfg(feature = "docs")]
   fn docs(&self) -> &'static str {
-    r#"Disallows the use of control flow statements within `finally` blocks.
-
-Use of the control flow statements (`return`, `throw`, `break` and `continue`) overrides the usage of any control flow statements that might have been used in the `try` or `catch` blocks, which is usually not the desired behaviour.
-
-### Invalid:
-
-```typescript
-let foo = function() {
-  try {
-    return 1;
-  } catch (err) {
-    return 2;
-  } finally {
-    return 3;
-  }
-};
-```
-
-```typescript
-let foo = function() {
-  try {
-    return 1;
-  } catch (err) {
-    return 2;
-  } finally {
-    throw new Error;
-  }
-};
-```
-
-### Valid:
-
-```typescript
-let foo = function() {
-  try {
-    return 1;
-  } catch (err) {
-    return 2;
-  } finally {
-    console.log("hola!");
-  }
-};
-```
-"#
+    include_str!("../../docs/rules/no_unsafe_finally.md")
   }
 }
 
 struct NoUnsafeFinallyHandler;
 
 impl Handler for NoUnsafeFinallyHandler {
-  fn break_stmt(&mut self, break_stmt: &AstView::BreakStmt, ctx: &mut Context) {
+  fn break_stmt(
+    &mut self,
+    break_stmt: &ast_view::BreakStmt,
+    ctx: &mut Context,
+  ) {
     let kind = StmtKind::Break(break_stmt.label);
     if stmt_inside_finally(break_stmt.span(), kind, break_stmt.as_node()) {
       add_diagnostic_with_hint(ctx, break_stmt.span(), kind);
@@ -119,7 +82,7 @@ impl Handler for NoUnsafeFinallyHandler {
 
   fn continue_stmt(
     &mut self,
-    continue_stmt: &AstView::ContinueStmt,
+    continue_stmt: &ast_view::ContinueStmt,
     ctx: &mut Context,
   ) {
     let kind = StmtKind::Continue(continue_stmt.label);
@@ -131,7 +94,7 @@ impl Handler for NoUnsafeFinallyHandler {
 
   fn return_stmt(
     &mut self,
-    return_stmt: &AstView::ReturnStmt,
+    return_stmt: &ast_view::ReturnStmt,
     ctx: &mut Context,
   ) {
     let kind = StmtKind::Return;
@@ -140,7 +103,11 @@ impl Handler for NoUnsafeFinallyHandler {
     }
   }
 
-  fn throw_stmt(&mut self, throw_stmt: &AstView::ThrowStmt, ctx: &mut Context) {
+  fn throw_stmt(
+    &mut self,
+    throw_stmt: &ast_view::ThrowStmt,
+    ctx: &mut Context,
+  ) {
     let kind = StmtKind::Throw;
     if stmt_inside_finally(throw_stmt.span(), kind, throw_stmt.as_node()) {
       add_diagnostic_with_hint(ctx, throw_stmt.span(), kind);
@@ -150,8 +117,8 @@ impl Handler for NoUnsafeFinallyHandler {
 
 #[derive(Clone, Copy)]
 enum StmtKind<'a> {
-  Break(Option<&'a AstView::Ident<'a>>),
-  Continue(Option<&'a AstView::Ident<'a>>),
+  Break(Option<&'a ast_view::Ident<'a>>),
+  Continue(Option<&'a ast_view::Ident<'a>>),
   Return,
   Throw,
 }
@@ -165,7 +132,7 @@ impl<'a> StmtKind<'a> {
     matches!(self, StmtKind::Continue(_))
   }
 
-  fn label(&self) -> Option<&'a AstView::Ident<'a>> {
+  fn label(&self) -> Option<&'a ast_view::Ident<'a>> {
     if let StmtKind::Break(label) | StmtKind::Continue(label) = self {
       *label
     } else {
@@ -178,9 +145,9 @@ impl<'a> StmtKind<'a> {
 fn stmt_inside_finally(
   stmt_span: Span,
   stmt_kind: StmtKind,
-  cur_node: AstView::Node,
+  cur_node: ast_view::Node,
 ) -> bool {
-  use AstView::Node::*;
+  use ast_view::Node::*;
   match (cur_node, stmt_kind.label()) {
     (Function(_), _) | (ArrowExpr(_), _) => false,
     (LabeledStmt(labeled_stmt), Some(label))
@@ -199,7 +166,7 @@ fn stmt_inside_finally(
       false
     }
     (
-      TryStmt(AstView::TryStmt {
+      TryStmt(ast_view::TryStmt {
         finalizer: Some(ref f),
         ..
       }),
