@@ -1,5 +1,6 @@
 // Copyright 2020-2021 the Deno authors. All rights reserved. MIT license.
-use super::{Context, LintRule, ProgramRef, DUMMY_NODE};
+use super::{Context, LintRule, DUMMY_NODE};
+use crate::ProgramRef;
 use derive_more::Display;
 use swc_ecmascript::ast::VarDecl;
 use swc_ecmascript::visit::noop_visit_type;
@@ -36,6 +37,11 @@ impl LintRule for SingleVarDeclarator {
       ProgramRef::Script(s) => visitor.visit_script(s, &DUMMY_NODE),
     }
   }
+
+  #[cfg(feature = "docs")]
+  fn docs(&self) -> &'static str {
+    include_str!("../../docs/rules/single_var_declarator.md")
+  }
 }
 
 struct SingleVarDeclaratorVisitor<'c, 'view> {
